{ config, lib, pkgs, inputs, ... }:

with lib;

let cfg = config.modules.services.photoprism;
in {
  options.modules.services.photoprism = {
    enable = mkOption {
      default = false;
      example = true;
    };
  };

  config = mkIf cfg.enable {
    services.nginx = {
      virtualHosts = {
        "gallery.vimium.com" = {
          forceSSL = true;
          enableACME = true;
          locations."/".proxyPass = "http://localhost:${config.services.photoprism.port}";
        };
      };
    };

    age.secrets."passwords/services/photoprism/admin" = {
      file = "${inputs.secrets}/passwords/services/photoprism/admin.age";
    };

    services.photoprism = {
      enable = true;
      address = "localhost";
      passwordFile = config.age.secrets."passwords/services/photoprism/admin".path;
      settings = {
        PHOTOPRISM_APP_NAME = "Vimium Gallery";
        PHOTOPRISM_SITE_AUTHOR = "Vimium";
        PHOTOPRISM_SITE_TITLE = "Vimium Gallery";
        PHOTOPRISM_SITE_CAPTION = "See your photos and videos on gallery.vimium.com";
        PHOTOPRISM_DISABLE_TLS = true;
        PHOTOPRISM_SPONSOR = true;
      };
    };
  };
}
